@@ -9,7 +9,7 @@
 #' directly, rather via this function, if and when it is necessary.
 #'  
 #' @param source A data source, for example \code{naio_10_cp1700}. 
-#'  \itemize{
+#'  \describe{
 ##'  \item{\code{naio_10_cp1700}}{ Symmetric input-output table at basic prices (product by product)}
 ##'  \item{\code{naio_10_pyp1700}}{ Symmetric input-output table at basic prices (product by product) (previous years prices)}
 ##'  \item{\code{naio_10_cp1750}}{ Symmetric input-output table at basic prices (industry by industry)}
@@ -62,8 +62,9 @@
 #' @importFrom forcats fct_reorder
 #' @importFrom lubridate year
 #' @importFrom utils data
-#' @importFrom rlang .data
+
 #' @family iotables import functions
+#' @autoglobal
 #' @examples 
 #' germany_table <- iotable_get( source = "germany_1995", 
 #'                  geo = 'DE', year = 1990, unit = "MIO_EUR", 
@@ -86,6 +87,7 @@ iotable_get <- function ( labelled_io_data = NULL,
   iotables_row <- iotables_col <- prod_na <- induse <- variable <-  NULL
   row_order <- col_order <- code <- label <- NULL
   uk_col <- uk_col_label <- uk_row <- uk_row_label <- indicator <- NULL
+  numeric_label <- iotables_label <- values <- NULL
 
   if ( labelling == 'eurostat' ) labelling <- 'short'
   ## Parameter exception handling -------------------------------------
@@ -129,17 +131,17 @@ iotable_get <- function ( labelled_io_data = NULL,
     
     metadata_rows <- getdata (metadata) %>%  #tables that follow prod_ind vocabulary
       dplyr::filter ( variable == "prod_na") %>%
-      dplyr::rename ( prod_na = .data$code) %>%
-      dplyr::rename ( prod_na_lab = .data$label ) %>%
-      dplyr::rename ( row_order = .data$numeric_label ) %>%
-      dplyr::rename ( iotables_row = .data$iotables_label )
+      dplyr::rename ( prod_na = code) %>%
+      dplyr::rename ( prod_na_lab = label ) %>%
+      dplyr::rename ( row_order = numeric_label ) %>%
+      dplyr::rename ( iotables_row = iotables_label )
     
     metadata_cols <- getdata(metadata) %>%
       dplyr::filter ( variable == "induse") %>%
-      dplyr::rename ( induse = .data$code) %>%
-      dplyr::rename ( induse_lab = .data$label )%>%
-      dplyr::rename ( col_order = .data$numeric_label ) %>%
-      dplyr::rename ( iotables_col = .data$iotables_label )
+      dplyr::rename ( induse = code) %>%
+      dplyr::rename ( induse_lab = label )%>%
+      dplyr::rename ( col_order = numeric_label ) %>%
+      dplyr::rename ( iotables_col = iotables_label )
     
     if ( source == "germany_1995" ) { 
       year <- 1990
@@ -159,17 +161,17 @@ iotable_get <- function ( labelled_io_data = NULL,
     
     metadata_rows <- metadata %>%
       dplyr::filter ( variable == "t_rows") %>%
-      dplyr::rename ( t_rows2 = .data$code) %>%
-      dplyr::rename ( t_rows2_lab = .data$label ) %>%
-      dplyr::rename ( row_order = .data$numeric_label ) %>%
-      dplyr::rename ( iotables_row = .data$iotables_label )
+      dplyr::rename ( t_rows2 = code) %>%
+      dplyr::rename ( t_rows2_lab = label ) %>%
+      dplyr::rename ( row_order = numeric_label ) %>%
+      dplyr::rename ( iotables_row = iotables_label )
     
     metadata_cols <- metadata %>%
       dplyr::filter ( variable == "t_cols") %>%
-      dplyr::rename ( t_cols2 = .data$code) %>%
-      dplyr::rename ( t_cols2_lab = .data$label ) %>%
-      dplyr::rename ( col_order = .data$numeric_label ) %>%
-      dplyr::rename ( iotables_col = .data$iotables_label )
+      dplyr::rename ( t_cols2 = code) %>%
+      dplyr::rename ( t_cols2_lab = label ) %>%
+      dplyr::rename ( col_order = numeric_label ) %>%
+      dplyr::rename ( iotables_col = iotables_label )
     
     year_input <- year
     geo_input <- geo
@@ -186,17 +188,17 @@ iotable_get <- function ( labelled_io_data = NULL,
       metadata_uk_2010 <- getdata(metadata_uk_2010)
       
       metadata_cols <- metadata_uk_2010  %>%
-        dplyr::filter ( !is.na(.data$uk_col)) %>%
+        dplyr::filter ( !is.na(uk_col)) %>%
         dplyr::select ( -uk_row, -uk_row_label, -prod_na, -row_order) %>%
-        mutate ( uk_col = gsub("\\.", "-", as.character(.data$uk_col))) %>%
-        mutate ( uk_col = gsub(" & ", "-", as.character(.data$uk_col))) %>%
-        mutate ( uk_col = trimws(.data$uk_col, 'both'))
+        mutate ( uk_col = gsub("\\.", "-", as.character(uk_col))) %>%
+        mutate ( uk_col = gsub(" & ", "-", as.character(uk_col))) %>%
+        mutate ( uk_col = trimws(uk_col, 'both'))
       
       metadata_rows <- metadata_uk_2010  %>%
-        filter ( !is.na(.data$uk_row)) %>%
+        filter ( !is.na(uk_row)) %>%
         select ( -all_of(c("uk_col", "uk_col_label", "induse", "col_order")) ) %>%
-        mutate ( uk_row = gsub("\\.", "-", as.character(.data$uk_row))) %>%
-        mutate ( uk_row = gsub(" & ", "-", as.character(.data$uk_row)))
+        mutate ( uk_row = gsub("\\.", "-", as.character(uk_row))) %>%
+        mutate ( uk_row = gsub(" & ", "-", as.character(uk_row)))
       
       prod_ind <- c(prod_ind, uk_tables)
     }  else {
@@ -238,19 +240,19 @@ iotable_get <- function ( labelled_io_data = NULL,
       
       croatia_2010_1700 <- getdata(croatia_2010_1700)
       labelled_io_data <- croatia_2010_1700 %>%
-        mutate ( year = lubridate::year(.data$time))
+        mutate ( year = lubridate::year(time))
       
     } else if ( source_inputed == "croatia_2010_1800" )  {
       
       croatia_2010_1800 <- getdata(croatia_2010_1800)
       labelled_io_data <- croatia_2010_1800   %>%
-        mutate ( year = lubridate::year (.data$time))
+        mutate ( year = lubridate::year (time))
       
     } else if ( source_inputed == "croatia_2010_1900" )  {
       
       croatia_2010_1900 <- getdata(croatia_2010_1900)
       labelled_io_data <- croatia_2010_1900 %>%
-        mutate ( year = lubridate::year(.data$time))
+        mutate ( year = lubridate::year(time))
       
     } else {
       if ( tmp_rds %in% list.files (path = tempdir()) ) {
@@ -267,27 +269,27 @@ iotable_get <- function ( labelled_io_data = NULL,
   if ( source %in% uk_tables ) {
     if ( source == "uk_2010_siot") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Input-Output table (domestic use, basic prices, product by product)')
+        dplyr::filter ( indicator == 'Input-Output table (domestic use, basic prices, product by product)')
     }
     
     if ( source == "uk_2010_use") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Domestic use table at basic prices (product by industry)')
+        dplyr::filter ( indicator == 'Domestic use table at basic prices (product by industry)')
     }
     
     if ( source == "uk_2010_imports") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Imports use table at basic prices (product by product)')
+        dplyr::filter ( indicator == 'Imports use table at basic prices (product by product)')
     }
     
     if ( source == "uk_2010_coeff") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Matrix of coefficients (product by product)')
+        dplyr::filter ( indicator == 'Matrix of coefficients (product by product)')
     }
     
     if ( source == "uk_2010_inverse") {
       labelled_io_data <- labelled_io_data %>%
-        dplyr::filter ( .data$indicator == 'Leontief Inverse (product by product)')
+        dplyr::filter ( indicator == 'Leontief Inverse (product by product)')
     }
   } 
    
@@ -423,19 +425,19 @@ iotable_get <- function ( labelled_io_data = NULL,
     iotable_labelled_w <- iotable_labelled %>%
       dplyr::arrange (iotables_row, iotables_col) %>%
       dplyr::select ( all_of(c("iotables_col", "iotables_row", "values")) ) %>% 
-      tidyr::spread (iotables_col, .data$values)
+      tidyr::spread (iotables_col, values)
     
   } else if ( labelling == "short" & source %in% prod_ind ) {
     
     iotable_labelled_w <- iotable_labelled %>%
-      dplyr::select (.data$prod_na, .data$induse, .data$values) %>%
-      dplyr::filter ( !is.na(.data$prod_na) )  %>%
-      tidyr::spread (induse, .data$values )
+      dplyr::select (prod_na, induse, values) %>%
+      dplyr::filter ( !is.na(prod_na) )  %>%
+      tidyr::spread (induse, values )
 
   } else {
     iotable_labelled_w <- iotable_labelled %>%
       dplyr::select ( all_of(c("t_rows2", "t_cols2", "values")) ) %>%
-      tidyr::spread ( t_cols2, .data$values )
+      tidyr::spread ( t_cols2, values )
   }
   
   if (!is.null(data_directory) ) {
